Arc class

Inheritance

Constructors

Arc({double innerRadius = 0, double outRadius = 0, Angle startAngle = Angle.zero, Angle sweepAngle = Angle.zero, double cornerRadius = 0, Angle padAngle = Angle.zero, Offset center = Offset.zero, double? padRadius})

Properties

annularSector AnnularSector
latefinal
area double
latefinal
asGeometry → Geometry
no setterinherited
bbox Rect
latefinal
center Offset
final
cornerRadius double
final
endAngle Angle
no setter
hashCode int
The hash code for this object.
no setteroverride
innerRadius double
final
isEmpty bool
no setter
length double
latefinal
outRadius double
final
padAngle Angle
final
padRadius double
latefinal
path Path
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startAngle Angle
final
sweepAngle Angle
final

Methods

buildGeometry() → Geometry
override
centerAngle() Angle
centroid() Offset
contains(BasicGeometry geom) bool
override
containsPoint(Offset p, {double eps = 1e-9}) bool
override
copy({double? innerRadius, double? outRadius, Angle? startAngle, Angle? sweepAngle, double? cornerRadius, Angle? padAngle, Offset? center, double? padRadius}) Arc
crossPoint(BasicGeometry geom) List<Offset>
inherited
crossPointWithRect(Rect rect) List<Offset>
inherited
distance(BasicGeometry geom) double
inherited
distanceWithPoint(Offset p) double
inherited
distanceWithRect(Rect rect) double
inherited
isOverlap(BasicGeometry geom, {double eps = 1e-9}) bool
是否有重叠 这个和JTS中的overlap有区别
override
isOverlapRect(Rect rect) bool
是否有重叠 这个和JTS中的overlap有区别
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBuildPath() Path
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

zero Arc
final