Curve class

Constructors

Curve({required Offset start, required Offset end, required Offset c1, required Offset c2})
Curve.of(Offset start, Offset c1, Offset c2, Offset end)

Properties

bezier → CubicBezier
final
boundary Rect
latefinal
c1 Offset
final
c2 Offset
final
end Offset
final
evenSpacer EvenSpacer2
latefinal
hashCode int
The hash code for this object.
no setteroverride
isLine bool
no setter
length double
no setter
path Path
no setter
reversed Curve
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Offset
final

Methods

computeSimilarity(Curve cubic) double
contains(Offset point) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointAt(double t) Offset
pointAtLength(double len) Offset
splitAtT(double t) List<Curve>
splitParts(int n) List<Curve>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

empty Curve
final