Line class final

Inheritance

Constructors

Line(Offset start, Offset end)

Properties

area double
no setteroverride
asGeometry → Geometry
no setteroverride
bbox Rect
no setteroverride
center Offset
no setteroverride
end Offset
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length double
no setteroverride
path Path
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segmentLine SegmentLine
no setter
start Offset
finalinherited
unitVector Offset
no setterinherited
vector Offset
no setterinherited

Methods

buildGeometry() → Geometry
override
contains(BasicGeometry geom) bool
override
containsPoint(Offset p, {double eps = 1e-9}) bool
override
crossPoint(BasicGeometry geom) List<Offset>
override
crossPointWithRect(Rect rect) List<Offset>
override
distance(BasicGeometry geom) double
override
distanceWithPoint(Offset p) double
override
distanceWithRect(Rect rect) double
override
isOverlap(BasicGeometry geom, {double eps = 1e-9}) bool
是否有重叠 这个和JTS中的overlap有区别
override
isOverlapRect(Rect rect) bool
是否有重叠 这个和JTS中的overlap有区别
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBuildPath() Path
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited