MultiLine class

Constructors

MultiLine()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clipPathWithRect(List<Offset> path, Rect rect) List<Offset>
给定路径点坐标和矩形区域范围 返回裁剪后的路径点坐标