QuadTree<T> class

Constructors

QuadTree(Accessor<T> xFun, Accessor<T> yFun, [double? x0, double? y0, double? x1, double? y1])

Properties

extent Rect?
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
no setter
xFun Accessor<T>
final
yFun Accessor<T>
final

Methods

add(T data) → void
addAll(List<T> data) → void
clear() → void
copy() QuadTree<T>
extend(double x0, double y0, double x1, double y1) → void
find(double x, double y, [double radius = double.infinity]) → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(T d) → void
toString() String
A string representation of this object.
inherited
visit(QuadTreeVisitor<T> visitor) → void
visitAfter(QuadTreeVisitor<T> visitor) → void
visitBFS(QuadTreeVisitor<T> visitor) → void
visitInOrder(QuadTreeVisitor<T> visitor) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromList<T>(Accessor<T> xFun, Accessor<T> yFun, List<T> nodes) QuadTree<T>