Angle extension type
- on
- Implemented types
- Available extensions
Constructors
- Angle(double radians)
- Angle.degrees(double degrees)
-
const
- Angle.radians(double radians)
-
const
Properties
- abs → Angle
-
no setter
-
address
→ Pointer<
Never> -
Available on double, provided by the DoubleAddress extension
The memory address of the underlying data.no setter - asDegrees → Angle
-
Available on num, provided by the NumberExt extension
no setter - asFixedNum → Num
-
Available on num, provided by the NumberExt extension
no setter - asPercentNum → Num
-
Available on num, provided by the NumberExt extension
no setter - asRadians → Angle
-
Available on num, provided by the NumberExt extension
no setter - cos → double
-
no setter
- degrees → double
-
no setter
- hashCode → int
-
Returns a hash code for a numerical value.
no setterinherited
- inverse → Angle
-
no setter
- isFinite → bool
-
Whether this number is finite.
no setterinherited
- isFull → bool
-
no setter
- isInfinite → bool
-
Whether this number is positive infinity or negative infinity.
no setterinherited
- isNaN → bool
-
Whether this number is a Not-a-Number value.
no setterinherited
- isNegative → bool
-
Whether this number is negative.
no setterinherited
- isZero → bool
-
no setter
- normalized → Angle
-
no setter
- radians → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sign → double
-
The sign of the double's numerical value.
no setterinherited
- sin → double
-
no setter
- tan → double
-
no setter
- toJS → JSNumber
-
Available on double, provided by the DoubleToJSNumber extension
Converts this double to a JSNumber.no setter - toJS → JSNumber
-
Available on num, provided by the NumToJSExtension extension
Converts this num to a JSNumber.no setter
Methods
-
abs(
) → double -
The absolute value of this number.
inherited
-
add(
num other, [bool otherIsDegrees = false]) → Angle -
ceil(
) → int -
Returns the least integer that is not smaller than this number.
inherited
-
ceilToDouble(
) → double -
Returns the least integer double value no smaller than
this.inherited -
clamp(
num lowerLimit, num upperLimit) → num -
Returns this num clamped to be in the range
lowerLimit-upperLimit.inherited -
compare(
num other, [double accurate = 1e-9]) → int -
compareTo(
num other) → int -
Compares this to
other.inherited -
div(
num factor) → Angle -
equal(
num other, [double accuracy = 1e-9]) → bool -
equals(
Angle other, {double epsilon = _epsilon}) → bool -
floor(
) → int -
Returns the greatest integer no greater than this number.
inherited
-
floorToDouble(
) → double -
Returns the greatest integer double value no greater than
this.inherited -
format(
{int precision = 4, String infinityChar = "∞"}) → String -
multiply(
num factor) → Angle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remainder(
num other) → double -
The remainder of the truncating division of
thisbyother.inherited -
rotate(
Angle delta) → Angle -
round(
) → int -
Returns the integer closest to this number.
inherited
-
roundToDouble(
) → double -
Returns the integer double value closest to
this.inherited -
sub(
num other, [bool otherIsDegrees = false]) → Angle -
toDouble(
) → double -
This number as a double.
inherited
-
toInt(
) → int -
Truncates this num to an integer and returns the result as an int.
inherited
-
toString(
) → String -
Provide a representation of this double value.
inherited
-
toStringAsExponential(
[int? fractionDigits]) → String -
An exponential string-representation of this number.
inherited
-
toStringAsFixed(
int fractionDigits) → String -
A decimal-point string-representation of this number.
inherited
-
toStringAsPrecision(
int precision) → String -
A string representation with
precisionsignificant digits.inherited -
toVector(
double length) → Offset -
truncate(
) → int -
Returns the integer obtained by discarding any fractional
part of this number.
inherited
-
truncateToDouble(
) → double -
Returns the integer double value obtained by discarding any fractional
digits from
this.inherited
Operators
-
operator %(
num factor) → Angle -
Euclidean modulo of this number by
other. -
operator *(
num factor) → Angle -
Multiplies this number by
other. -
operator +(
Angle other) → Angle -
Adds
otherto this number. -
operator -(
Angle other) → Angle -
Subtracts
otherfrom this number. -
operator /(
num factor) → Angle -
Divides this number by
other. -
operator <(
Angle other) → bool -
Whether this number is numerically smaller than
other. -
operator <=(
Angle other) → bool -
Whether this number is numerically smaller than or equal to
other. -
operator ==(
Object other) → bool -
Test whether this value is numerically equal to
other.inherited -
operator >(
Angle other) → bool -
Whether this number is numerically greater than
other. -
operator >=(
Angle other) → bool -
Whether this number is numerically greater than or equal to
other. -
operator unary-(
) → Angle -
Subtracts
otherfrom this number. -
operator ~/(
num other) → int -
Truncating division operator.
inherited