BinaryHeapArray<T> class
- Implemented types
-
- BinaryHeap<
T>
- BinaryHeap<
Constructors
- BinaryHeapArray(int compareFun(T a, T b), [HeapType type = HeapType.min])
Properties
- compareFun → int Function(T a, T b)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
no setteroverride
- type ↔ HeapType
-
latefinal
Methods
-
add(
T value) → bool -
override
-
clear(
) → void -
override
-
contains(
T value) → bool -
override
-
getHeadValue(
) → T? -
override
-
getHeap(
) → List< T> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
T value) → T? -
override
-
removeHead(
) → T? -
override
-
toCollection(
) → Iterable< T> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → bool -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited