BoundsUtil class final
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
arcBounds(
{required Offset center, required double ir, required double or, required Angle startAngle, required Angle sweepAngle}) → Rect -
boundsOf<
T> (Iterable< T> nodes, double leftFun(T node), double topFun(T node), double rightFun(T node), double bottomFun(T node)) → Rect? -
pointsBounds(
Iterable< Offset?> rects) → Rect? -
rectsBounds(
Iterable< Rect?> rects) → Rect?